from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNNotificationSettings(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(UserNotifications.UNAlertStyle)
        self.assertIsEnumType(UserNotifications.UNAuthorizationStatus)
        self.assertIsEnumType(UserNotifications.UNNotificationSetting)
        self.assertIsEnumType(UserNotifications.UNShowPreviewsSetting)

    def test_constants(self):
        self.assertEqual(UserNotifications.UNAuthorizationStatusNotDetermined, 0)
        self.assertEqual(UserNotifications.UNAuthorizationStatusDenied, 1)
        self.assertEqual(UserNotifications.UNAuthorizationStatusAuthorized, 2)
        self.assertEqual(UserNotifications.UNAuthorizationStatusProvisional, 3)

        self.assertEqual(UserNotifications.UNShowPreviewsSettingAlways, 0)
        self.assertEqual(UserNotifications.UNShowPreviewsSettingWhenAuthenticated, 1)
        self.assertEqual(UserNotifications.UNShowPreviewsSettingNever, 2)

        self.assertEqual(UserNotifications.UNNotificationSettingNotSupported, 0)
        self.assertEqual(UserNotifications.UNNotificationSettingDisabled, 1)
        self.assertEqual(UserNotifications.UNNotificationSettingEnabled, 2)

        self.assertEqual(UserNotifications.UNAlertStyleNone, 0)
        self.assertEqual(UserNotifications.UNAlertStyleBanner, 1)
        self.assertEqual(UserNotifications.UNAlertStyleAlert, 2)

    def test_methods(self):
        self.assertResultIsBOOL(
            UserNotifications.UNNotificationSettings.providesAppNotificationSettings
        )



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 19:28:13 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$UNErrorDomain$UNNotificationAttachmentOptionsThumbnailClippingRectKey$UNNotificationAttachmentOptionsThumbnailHiddenKey$UNNotificationAttachmentOptionsThumbnailTimeKey$UNNotificationAttachmentOptionsTypeHintKey$UNNotificationDefaultActionIdentifier$UNNotificationDismissActionIdentifier$UNNotificationInterruptionReasonAccountSecurity$UNNotificationInterruptionReasonApprovalRequest$UNNotificationInterruptionReasonHealthAndWellness$UNNotificationInterruptionReasonHomeSecurity$UNNotificationInterruptionReasonLocalSafety$UNNotificationInterruptionReasonOrderPickup$UNNotificationInterruptionReasonPackageDelivery$UNNotificationInterruptionReasonSchedule$UNNotificationInterruptionReasonTimeExpired$UNNotificationInterruptionReasonTransportationDeparting$UNNotificationInterruptionReasonUrgentMessage$"""
enums = """$UNAlertStyleAlert@2$UNAlertStyleBanner@1$UNAlertStyleNone@0$UNAuthorizationOptionAlert@4$UNAuthorizationOptionAnnouncement@128$UNAuthorizationOptionBadge@1$UNAuthorizationOptionCarPlay@8$UNAuthorizationOptionCriticalAlert@16$UNAuthorizationOptionNone@0$UNAuthorizationOptionProvidesAppNotificationSettings@32$UNAuthorizationOptionProvisional@64$UNAuthorizationOptionSound@2$UNAuthorizationOptionTimeSensitive@256$UNAuthorizationStatusAuthorized@2$UNAuthorizationStatusDenied@1$UNAuthorizationStatusEphemeral@4$UNAuthorizationStatusNotDetermined@0$UNAuthorizationStatusProvisional@3$UNErrorCodeAttachmentCorrupt@105$UNErrorCodeAttachmentInvalidFileSize@102$UNErrorCodeAttachmentInvalidURL@100$UNErrorCodeAttachmentMoveIntoDataStoreFailed@104$UNErrorCodeAttachmentNotInDataStore@103$UNErrorCodeAttachmentUnrecognizedType@101$UNErrorCodeContentProvidingInvalid@1501$UNErrorCodeContentProvidingObjectNotAllowed@1500$UNErrorCodeNotificationInvalidNoContent@1401$UNErrorCodeNotificationInvalidNoDate@1400$UNErrorCodeNotificationsNotAllowed@1$UNNotificationActionOptionAuthenticationRequired@1$UNNotificationActionOptionDestructive@2$UNNotificationActionOptionForeground@4$UNNotificationActionOptionNone@0$UNNotificationCategoryOptionAllowAnnouncement@16$UNNotificationCategoryOptionAllowInCarPlay@2$UNNotificationCategoryOptionCustomDismissAction@1$UNNotificationCategoryOptionHiddenPreviewsShowSubtitle@8$UNNotificationCategoryOptionHiddenPreviewsShowTitle@4$UNNotificationCategoryOptionNone@0$UNNotificationGroupingSettingDefault@0$UNNotificationGroupingSettingOff@2$UNNotificationGroupingSettingSource@1$UNNotificationInterruptionLevelActive@1$UNNotificationInterruptionLevelCritical@3$UNNotificationInterruptionLevelPassive@0$UNNotificationInterruptionLevelTimeSensitive@2$UNNotificationPresentationOptionAlert@4$UNNotificationPresentationOptionBadge@1$UNNotificationPresentationOptionBanner@16$UNNotificationPresentationOptionList@8$UNNotificationPresentationOptionNone@0$UNNotificationPresentationOptionSound@2$UNNotificationSettingDisabled@1$UNNotificationSettingEnabled@2$UNNotificationSettingNotSupported@0$UNShowPreviewsSettingAlways@0$UNShowPreviewsSettingNever@2$UNShowPreviewsSettingWhenAuthenticated@1$"""
misc.update(
    {
        "UNNotificationCategoryOptions": NewType("UNNotificationCategoryOptions", int),
        "UNAlertStyle": NewType("UNAlertStyle", int),
        "UNNotificationInterruptionLevel": NewType(
            "UNNotificationInterruptionLevel", int
        ),
        "UNAuthorizationOptions": NewType("UNAuthorizationOptions", int),
        "UNNotificationActionOptions": NewType("UNNotificationActionOptions", int),
        "UNShowPreviewsSetting": NewType("UNShowPreviewsSetting", int),
        "UNAuthorizationStatus": NewType("UNAuthorizationStatus", int),
        "UNNotificationSetting": NewType("UNNotificationSetting", int),
        "UNErrorCode": NewType("UNErrorCode", int),
        "UNNotificationPresentationOptions": NewType(
            "UNNotificationPresentationOptions", int
        ),
    }
)
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"userNotificationCenter:didReceiveNotificationResponse:withCompletionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"userNotificationCenter:openSettingsForNotification:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"userNotificationCenter:willPresentNotification:withCompletionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Q"}},
                    },
                    "type": "@?",
                },
            },
        },
    )
    r(
        b"UNCalendarNotificationTrigger",
        b"triggerWithDateMatchingComponents:repeats:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"UNLocationNotificationTrigger",
        b"triggerWithRegion:repeats:",
        {"arguments": {3: {"type": "Z"}}},
    )
    r(
        b"UNNotificationAttachment",
        b"attachmentWithIdentifier:URL:options:error:",
        {"arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"UNNotificationServiceExtension",
        b"didReceiveNotificationRequest:withContentHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"UNNotificationSettings",
        b"providesAppNotificationSettings",
        {"retval": {"type": "Z"}},
    )
    r(b"UNNotificationTrigger", b"repeats", {"retval": {"type": "Z"}})
    r(
        b"UNTimeIntervalNotificationTrigger",
        b"triggerWithTimeInterval:repeats:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(
        b"UNUserNotificationCenter",
        b"addNotificationRequest:withCompletionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"UNUserNotificationCenter",
        b"getDeliveredNotificationsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"UNUserNotificationCenter",
        b"getNotificationCategoriesWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"UNUserNotificationCenter",
        b"getNotificationSettingsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"UNUserNotificationCenter",
        b"getPendingNotificationRequestsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"UNUserNotificationCenter",
        b"requestAuthorizationWithOptions:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"Z"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"UNUserNotificationCenter",
        b"supportsContentExtensions",
        {"retval": {"type": "Z"}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase
import UserNotifications
import objc


class TestUNUserNotificationCenterHelper(UserNotifications.NSObject):
    def userNotificationCenter_willPresentNotification_withCompletionHandler_(
        self, a, b, c
    ):
        pass

    def userNotificationCenter_didReceiveNotificationResponse_withCompletionHandler_(
        self, a, b, c
    ):
        pass

    def userNotificationCenter_openSettingsForNotification_(self, a, b):
        pass


class TestUNUserNotificationCenter(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(UserNotifications.UNAuthorizationOptions)
        self.assertIsEnumType(UserNotifications.UNNotificationPresentationOptions)

    def test_constants(self):
        self.assertEqual(UserNotifications.UNAuthorizationOptionBadge, 1 << 0)
        self.assertEqual(UserNotifications.UNAuthorizationOptionSound, 1 << 1)
        self.assertEqual(UserNotifications.UNAuthorizationOptionAlert, 1 << 2)
        self.assertEqual(UserNotifications.UNAuthorizationOptionCarPlay, 1 << 3)
        self.assertEqual(UserNotifications.UNAuthorizationOptionCriticalAlert, 1 << 4)
        self.assertEqual(
            UserNotifications.UNAuthorizationOptionProvidesAppNotificationSettings,
            1 << 5,
        )
        self.assertEqual(UserNotifications.UNAuthorizationOptionProvisional, 1 << 6)
        self.assertEqual(UserNotifications.UNAuthorizationOptionNone, 0)

        self.assertEqual(
            UserNotifications.UNNotificationPresentationOptionBadge, 1 << 0
        )
        self.assertEqual(
            UserNotifications.UNNotificationPresentationOptionSound, 1 << 1
        )
        self.assertEqual(
            UserNotifications.UNNotificationPresentationOptionAlert, 1 << 2
        )
        self.assertEqual(UserNotifications.UNNotificationPresentationOptionList, 1 << 3)
        self.assertEqual(
            UserNotifications.UNNotificationPresentationOptionBanner, 1 << 4
        )
        self.assertEqual(UserNotifications.UNNotificationPresentationOptionNone, 0)

    def test_methods(self):
        self.assertResultIsBOOL(
            UserNotifications.UNUserNotificationCenter.supportsContentExtensions
        )
        self.assertArgIsBlock(
            UserNotifications.UNUserNotificationCenter.requestAuthorizationWithOptions_completionHandler_,  # noqa: B950
            1,
            b"vZ@",
        )
        self.assertArgIsBlock(
            UserNotifications.UNUserNotificationCenter.getNotificationCategoriesWithCompletionHandler_,  # noqa: B950
            0,
            b"v@",
        )
        self.assertArgIsBlock(
            UserNotifications.UNUserNotificationCenter.getNotificationSettingsWithCompletionHandler_,  # noqa: B950
            0,
            b"v@",
        )
        self.assertArgIsBlock(
            UserNotifications.UNUserNotificationCenter.addNotificationRequest_withCompletionHandler_,  # noqa: B950
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            UserNotifications.UNUserNotificationCenter.getPendingNotificationRequestsWithCompletionHandler_,  # noqa: B950
            0,
            b"v@",
        )
        self.assertArgIsBlock(
            UserNotifications.UNUserNotificationCenter.getDeliveredNotificationsWithCompletionHandler_,  # noqa: B950
            0,
            b"v@",
        )

        self.assertArgIsBlock(
            TestUNUserNotificationCenterHelper.userNotificationCenter_willPresentNotification_withCompletionHandler_,  # noqa: B950
            2,
            b"v" + objc._C_NSUInteger,
        )
        self.assertArgIsBlock(
            TestUNUserNotificationCenterHelper.userNotificationCenter_didReceiveNotificationResponse_withCompletionHandler_,  # noqa: B950
            2,
            b"v",
        )

    def test_protocols(self):
        objc.protocolNamed("UNUserNotificationCenterDelegate")



"""
Python mapping for the UserNotifications framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from UserNotifications import _metadata
from UserNotifications import _UserNotifications

sys.modules["UserNotifications"] = mod = objc.ObjCLazyModule(
    "UserNotifications",
    "com.apple.UserNotifications",
    objc.pathForFramework("/System/Library/Frameworks/UserNotifications.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_UserNotifications, Foundation),
)


del sys.modules["UserNotifications._metadata"]



from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNNotificationAction(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(UserNotifications.UNNotificationActionOptions)

    def test_constants(self):
        self.assertEqual(UserNotifications.UNNotificationActionOptionNone, 0)
        self.assertEqual(
            UserNotifications.UNNotificationActionOptionAuthenticationRequired, 1 << 0
        )
        self.assertEqual(
            UserNotifications.UNNotificationActionOptionDestructive, 1 << 1
        )
        self.assertEqual(UserNotifications.UNNotificationActionOptionForeground, 1 << 2)

    def test_classes(self):
        UserNotifications.UNNotificationAction



from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNNotificationCategory(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(UserNotifications.UNNotificationCategoryOptions)

    def test_constants(self):
        self.assertEqual(
            UserNotifications.UNNotificationCategoryOptionCustomDismissAction, 1 << 0
        )
        self.assertEqual(
            UserNotifications.UNNotificationCategoryOptionAllowInCarPlay, 1 << 1
        )
        self.assertEqual(
            UserNotifications.UNNotificationCategoryOptionHiddenPreviewsShowTitle,
            1 << 2,
        )
        self.assertEqual(
            UserNotifications.UNNotificationCategoryOptionHiddenPreviewsShowSubtitle,
            1 << 3,
        )
        self.assertEqual(UserNotifications.UNNotificationCategoryOptionNone, 0)



from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNNotificationAttachment(TestCase):
    def test_constants(self):
        self.assertIsInstance(
            UserNotifications.UNNotificationAttachmentOptionsTypeHintKey, str
        )
        self.assertIsInstance(
            UserNotifications.UNNotificationAttachmentOptionsThumbnailHiddenKey, str
        )
        self.assertIsInstance(
            UserNotifications.UNNotificationAttachmentOptionsThumbnailClippingRectKey,
            str,
        )
        self.assertIsInstance(
            UserNotifications.UNNotificationAttachmentOptionsThumbnailTimeKey, str
        )

    def test_methods(self):
        self.assertArgIsOut(
            UserNotifications.UNNotificationAttachment.attachmentWithIdentifier_URL_options_error_,  # noqa: B950
            3,
        )



from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNNotificationServiceExtension(TestCase):
    def test_methods(self):
        self.assertArgIsBlock(
            UserNotifications.UNNotificationServiceExtension.didReceiveNotificationRequest_withContentHandler_,  # noqa: B950
            1,
            b"v@",
        )



from PyObjCTools.TestSupport import TestCase, min_sdk_level, min_os_level
import UserNotifications
import objc


class TestUNNotificationContent(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(UserNotifications.UNNotificationInterruptionLevel)

    def test_constants(self):
        self.assertEqual(UserNotifications.UNNotificationInterruptionLevelPassive, 0)
        self.assertEqual(UserNotifications.UNNotificationInterruptionLevelActive, 1)
        self.assertEqual(
            UserNotifications.UNNotificationInterruptionLevelTimeSensitive, 2
        )
        self.assertEqual(UserNotifications.UNNotificationInterruptionLevelCritical, 3)

    @min_sdk_level("12.0")
    def test_protocols12_0(self):
        objc.protocolNamed("UNNotificationContentProviding")

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertArgIsOut(
            UserNotifications.UNNotificationContent.contentByUpdatingWithProvider_error_,
            1,
        )



from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNNotificationResponse(TestCase):
    def test_constants(self):
        self.assertIsInstance(
            UserNotifications.UNNotificationDefaultActionIdentifier, str
        )
        self.assertIsInstance(
            UserNotifications.UNNotificationDismissActionIdentifier, str
        )



from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNError(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(UserNotifications.UNErrorCode)

    def test_constants(self):
        self.assertEqual(UserNotifications.UNErrorCodeNotificationsNotAllowed, 1)
        self.assertEqual(UserNotifications.UNErrorCodeAttachmentInvalidURL, 100)
        self.assertEqual(UserNotifications.UNErrorCodeAttachmentUnrecognizedType, 101)
        self.assertEqual(UserNotifications.UNErrorCodeAttachmentInvalidFileSize, 102)
        self.assertEqual(UserNotifications.UNErrorCodeAttachmentNotInDataStore, 103)
        self.assertEqual(
            UserNotifications.UNErrorCodeAttachmentMoveIntoDataStoreFailed, 104
        )
        self.assertEqual(UserNotifications.UNErrorCodeAttachmentCorrupt, 105)
        self.assertEqual(UserNotifications.UNErrorCodeNotificationInvalidNoDate, 1400)
        self.assertEqual(
            UserNotifications.UNErrorCodeNotificationInvalidNoContent, 1401
        )
        self.assertEqual(
            UserNotifications.UNErrorCodeContentProvidingObjectNotAllowed, 1500
        )
        self.assertEqual(UserNotifications.UNErrorCodeContentProvidingInvalid, 1501)



from PyObjCTools.TestSupport import TestCase
import UserNotifications


class TestUNNotificationTrigger(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(UserNotifications.UNNotificationTrigger.repeats)
        self.assertArgIsBOOL(
            UserNotifications.UNTimeIntervalNotificationTrigger.triggerWithTimeInterval_repeats_,  # noqa: B950
            1,
        )
        self.assertArgIsBOOL(
            UserNotifications.UNCalendarNotificationTrigger.triggerWithDateMatchingComponents_repeats_,  # noqa: B950
            1,
        )
        self.assertArgIsBOOL(
            UserNotifications.UNLocationNotificationTrigger.triggerWithRegion_repeats_,
            1,
        )
